# TestPointAnalyticResult


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_group_by_status** | [**[TestPlanGroupByStatus], none_type**](TestPlanGroupByStatus.md) |  | [optional] 
**sum_group_by_tester** | [**[TestPlanGroupByTester], none_type**](TestPlanGroupByTester.md) |  | [optional] 
**count_group_by_tester** | [**[TestPlanGroupByTester], none_type**](TestPlanGroupByTester.md) |  | [optional] 
**count_group_by_test_suite** | [**[TestPlanGroupByTestSuite], none_type**](TestPlanGroupByTestSuite.md) |  | [optional] 
**count_group_by_tester_and_status** | [**[TestPlanGroupByTesterAndStatus], none_type**](TestPlanGroupByTesterAndStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


